@@ -1,13 +1,27 @@
-#' Quickly graph networks with sensible defaults
+#' Easily graph networks with sensible defaults
 #' 
 #' @description 
-#' The aim of this function is to provide users with a quick and easy
-#' graphing function that makes best use of the data,
-#' whatever its composition.
-#' Users can also tailor the plot according to their
-#' preferences regarding node size, colour, and shape.
-#' The function also supports visualisation
-#' of network measures such as centrality.
+#'   This function provides users with an easy way to graph
+#'   (m)any network data for exploration, investigation, and communication.
+#'   
+#'   It builds upon `{ggplot2}` and `{ggraph}` to offer
+#'   pretty and extensible graphing solutions.
+#'   However, compared to those solutions, 
+#'   `autographr()` contains various algorithms to provide better looking
+#'   graphs by default.
+#'   This means that just passing the function some network data
+#'   will often be sufficient to return a reasonable-looking graph.
+#'   
+#'   The function also makes it easy to modify many of the most
+#'   commonly adapted aspects of a graph, 
+#'   including node and edge size, colour, and shape,
+#'   as arguments rather than additional functions that you need to remember.
+#'   These can be defined outright, e.g. `node_size = 8`,
+#'   or in reference to an attribute of the network, e.g. `node_size = "wealth"`.
+#'   
+#'   Lastly, `autographr()` uses ggplot2-related theme information,
+#'   so it is easy to make colour palette and fonts institution-specific and consistent.
+#'   See e.g. `theme_iheid()` for more.
 #' @family mapping
 #' @param .data A manynet-consistent object.
 #' @param layout An igraph, ggraph, or manynet layout algorithm.
@@ -59,56 +73,40 @@
 #'   It is easiest if this is added as an edge or tie attribute 
 #'   to the graph before plotting.
 #'   Edges can also be colored by declaring a color instead.
-#' @param edge_size Edge variable to be used for sizing the edges.
+#' @param edge_size Tie variable to be used for sizing the edges.
 #'   This can be any continuous variable on the nodes of the network.
 #'   Since this function expects this to be an existing variable,
 #'   it is recommended to calculate all edge-related statistics prior
 #'   to using this function.
 #'   Edges can also be sized by declaring a numeric size or vector instead.
-#' @param ... Extra arguments to pass on to layout.
-#' @return A ggplot2::ggplot() object.
+#' @param ... Extra arguments to pass on to the layout algorithm, if necessary.
+#' @return A `ggplot2::ggplot()` object.
+#'   The last plot can be saved to the file system using `ggplot2::ggsave()`.
 #' @importFrom ggraph geom_edge_link geom_node_text geom_conn_bundle
 #' get_con geom_node_point scale_edge_width_continuous geom_node_label
 #' @importFrom ggplot2 aes arrow unit scale_color_brewer scale_fill_brewer
-#' @name autographing
-NULL
-
-#' @describeIn autographing Graphs a network with sensible defaults
 #' @examples
-#' #autographr(ison_adolescents)
-#' #ison_adolescents %>%
-#' # mutate(year = rep(c(1985, 1990, 1995, 2000), times = 2)) %>%
-#' #autographr(layout = "lineage", rank = "year")
-#' #autographr(ison_algebra, layout = "circle",
-#' #          node_size = 8, node_color = "orange", node_shape = "square",
-#' #          edge_color = "blue", edge_size = 2)
-#' #autographr(ison_algebra, edge_color = "type",
-#' #          node_size = migraph::node_betweenness(ison_algebra)*100)
-#' #ison_adolescents %>%
-#' #   mutate(cut = node_is_cutpoint(ison_adolescents)) %>%
-#' #autographr(node_color = "cut", node_shape = "cut")
+#' autographr(ison_adolescents)
+#' ison_adolescents |>
+#'   mutate(color = rep(c("extrovert", "introvert"), times = 4),
+#'          size = ifelse(node_is_cutpoint(ison_adolescents), 6, 3)) |>
+#'   mutate_ties(ecolor = rep(c("friends", "aquaintances"), times = 5)) |>
+#'   autographr(node_color = "color", node_size = "size",
+#'              edge_size = 1.5, edge_color = "ecolor")
 #' #autographr(ison_lotr, node_color = Race,
-#' #            node_size = migraph::node_degree(ison_lotr)*2,
-#' #            edge_color = "darkgreen",
-#' #          edge_size = migraph::tie_degree(ison_lotr))
+#' #           node_size = migraph::node_degree(ison_lotr)*2,
+#' #           edge_color = "darkgreen",
+#' #           edge_size = migraph::tie_degree(ison_lotr))
 #' #autographr(ison_karateka, node_group = allegiance,
-#' #            edge_size = migraph::tie_closeness(ison_karateka))
-#' #autographr(ison_southern_women, layout = "concentric",
-#' #            node_color = "type", membership = "type")
-#' #autographr(ison_southern_women, layout = "hierarchy", center = "events")
-#' #autographr(ison_lotr, layout = "multilevel", 
-#' #            node_color = "Race", level = "Race")
-#' #autographr(play_diffusion(ison_karateka))
+#' #           edge_size = migraph::tie_closeness(ison_karateka))
 #' @export
 autographr <- function(.data, layout, labels = TRUE,
                        node_color, node_shape, node_size, node_group,
                        edge_color, edge_size, ...) {
   g <- as_tidygraph(.data)
   if (missing(layout)) {
-    if (length(g) == 3) {
-      layout <- "triad" 
-    } else if (length(g) == 4) {
-      layout <- "quad" 
+    if (length(g) == 3 | length(g) == 4) {
+      layout <- "configuration"
     } else if (is_twomode(g)) {
       layout <- "hierarchy"
     } else layout <- "stress"
@@ -139,15 +137,42 @@ autographr <- function(.data, layout, labels = TRUE,
   p
 }
 
-#' @describeIn autographing Graphs a list of networks 
-#'   with sensible defaults
+#' @rdname autographr
+#' @export
+graphr <- autographr
+
+#' Easily graph a set of networks with sensible defaults
+#' 
+#' @description 
+#'   This function provides users with an easy way to graph
+#'   lists of network data for comparison.
+#'   
+#'   It builds upon this package's `autographr()` function, 
+#'   and inherits all the same features and arguments.
+#'   See `autographr()` for more.
+#'   However, it uses the `{patchwork}` package to plot the graphs
+#'   side by side and, if necessary, in successive rows.
+#'   This is useful for lists of networks that represent, for example, 
+#'   ego or component subgraphs of a network,
+#'   or a list of a network's different types of tie or across time.
+#'   By default just the first and last network will be plotted,
+#'   but this can be overridden by the "waves" parameter.
+#'   
+#'   Where the graphs are of the same network (same nodes),
+#'   the graphs may share a layout to facilitate comparison.
+#'   By default, successive graphs will use the layout calculated for 
+#'   the "first" network, but other options include the "last" layout,
+#'   or a mix, "both", of them.
+#' @family mapping
 #' @param netlist A list of manynet-compatible networks.
-#' @param waves The number of plots to be displayed side-by-side.
+#' @param waves Numeric, the number of plots to be displayed side-by-side.
 #'   If missing, the number of plots will be reduced to the first and last
 #'   when there are more than four plots.
+#'   This argument can also be passed a vector selecting the waves to plot.
 #' @param based_on Whether the layout of the joint plots should
-#'   be based on the "first" or the "last" network.
-#' @source http://blog.schochastics.net/post/animating-network-evolutions-with-gganimate/
+#'   be based on the "first" or the "last" network, or "both".
+#' @param ... Additional arguments passed to `autographr()`.
+#' @return Multiple `ggplot2::ggplot()` objects displayed side-by-side.
 #' @examples
 #' #autographs(to_egos(ison_adolescents))
 #' #autographs(to_egos(ison_adolescents), waves = 8)
@@ -155,8 +180,9 @@ autographr <- function(.data, layout, labels = TRUE,
 #' #autographs(play_diffusion(ison_adolescents))
 #' @export
 autographs <- function(netlist, waves,
-                       based_on = "first", ...) {
+                       based_on = c("first", "last", "both"), ...) {
   thisRequires("patchwork")
+  based_on <- match.arg(based_on)
   if (any(class(netlist) == "diff_model")) netlist <- to_waves(netlist)
   if (missing(waves)) {
     if (length(netlist) > 4) {
@@ -168,7 +194,7 @@ autographs <- function(netlist, waves,
       netlist <- netlist[waves]
   }
   if (is.null(names(netlist))) names(netlist) <- rep("", length(netlist))
-  if (length(unique(unname(lapply(netlist, length)))) == 1) {
+  if (length(unique(lapply(netlist, length))) == 1) {
     if (based_on == "first") {
       lay <- autographr(netlist[[1]], ...)
       x <- lay$data$x
@@ -188,46 +214,71 @@ autographs <- function(netlist, waves,
     gs <- lapply(1:length(netlist), function(i)
       autographr(netlist[[i]], x = x, y = y, ...) + ggtitle(names(netlist)[i]))
   } else {
-    message("Layouts were not standardised since nodes appear across waves.")
+    message("Layouts were not standardised since not all nodes appear across waves.")
     gs <- lapply(1:length(netlist), function(i)
       autographr(netlist[[i]], ...) + ggtitle(names(netlist)[i]))
   }
-  if (all(c("Infected", "Exposed", "Recovered") %in% names(gs[[1]]$data))) {
-    gs <- collapse_guides(gs)
-  }
+  # if (all(c("Infected", "Exposed", "Recovered") %in% names(gs[[1]]$data))) {
+  #   gs <- .collapse_guides(gs)
+  # }
   do.call(patchwork::wrap_plots, c(gs, list(guides = "collect")))
 }
 
-#' @describeIn autographing Graphs an dynamic (animated) network
-#'   with sensible defaults
+#' @rdname autographs
+#' @export
+graphs <- autographs
+
+#' Easily animate dynamic networks with sensible defaults
+#' 
+#' @description 
+#'   This function provides users with an easy way to graph
+#'   dynamic network data for exploration and presentation.
+#'   
+#'   It builds upon this package's `autographr()` function, 
+#'   and inherits all the same features and arguments.
+#'   See `autographr()` for more.
+#'   However, it uses the `{gganimate}` package to animate the changes
+#'   between successive iterations of a network.
+#'   This is useful for networks in which the ties and/or the node or tie
+#'   attributes are changing.
+#'   
+#'   A progress bar is shown if it takes some time to encoding all the
+#'   .png files into a .gif.
+#' @family mapping
 #' @param tlist The same migraph-compatible network listed according to
 #'   a time attribute, waves, or slices.
-#' @param keep_isolates Would you like to remove vertices that do not have
-#'   any adjacent edges in each frame?
+#' @param keep_isolates Logical, whether to keep isolate nodes in the graph.
 #'   TRUE by default.
-#'   If FALSE, deletes isolated vertices in each frame.
+#'   If FALSE, removes nodes from each frame they are isolated in.
+#' @inheritParams autographr
 #' @importFrom igraph gsize as_data_frame get.edgelist
 #' @importFrom ggplot2 ggplot geom_segment geom_point geom_text
 #' scale_alpha_manual theme_void
 #' @importFrom ggraph create_layout
 #' @importFrom dplyr mutate select distinct left_join %>%
-#' @source http://blog.schochastics.net/post/animating-network-evolutions-with-gganimate/
+#' @source https://blog.schochastics.net/posts/2021-09-15_animating-network-evolutions-with-gganimate/
+#' @return Shows a .gif image. Assigning the result of the function
+#'   saves the gif to a temporary folder and the object holds the path to this file.
 #' @examples
 #' #ison_adolescents %>%
 #' #  mutate_ties(year = sample(1995:1998, 10, replace = TRUE)) %>%
 #' #  to_waves(attribute = "year", cumulative = TRUE) %>%
 #' #  autographd()
-#' #ison_adolescents %>%
-#' #  mutate(shape = rep(c("circle", "square"), times = 4),
-#' #         color = rep(c("blue", "red"), times = 4),
-#' #         size = sample(4:16, 8, replace = TRUE)) %>%
-#' #  mutate_ties(year = sample(1995:1998, 10, replace = TRUE)) %>%
+#' #ison_adolescents %>% 
+#' #  mutate(gender = rep(c("male", "female"), times = 4),
+#' #         hair = rep(c("black", "brown"), times = 4),
+#' #         age = sample(11:16, 8, replace = TRUE)) %>%
+#' #  mutate_ties(year = sample(1995:1998, 10, replace = TRUE),
+#' #              links = sample(c("friends", "not_friends"), 10, replace = TRUE),
+#' #              weekly_meetings = sample(c(3, 5, 7), 10, replace = TRUE)) %>%
 #' #  to_waves(attribute = "year") %>%
-#' #  autographd(layout = "circle", node_shape = "shape",
-#' #             node_color = "color", node_size =  "size")
-#' #autographd(play_diffusion(ison_adolescents, seeds = 5, recovery = 0.1))
+#' #  autographd(layout = "concentric", membership = "gender",
+#' #             node_shape = "gender", node_color = "hair",
+#' #             node_size =  "age", edge_color = "links",
+#' #             edge_size = "weekly_meetings")
+#' #autographd(play_diffusion(ison_adolescents, seeds = 5))
 #' @export
-autographd <- function(tlist, layout, labels = TRUE,
+autographt <- function(tlist, layout, labels = TRUE,
                        node_color, node_shape, node_size,
                        edge_color, edge_size, keep_isolates = TRUE, ...) {
   thisRequires("gganimate")
@@ -257,9 +308,7 @@ autographd <- function(tlist, layout, labels = TRUE,
     edge_size <- as.character(substitute(edge_size))
   }
   # Check if diffusion model
-  if (inherits(tlist, "diff_model")) {
-    tlist <- to_waves(tlist)
-  }
+  if (inherits(tlist, "diff_model")) tlist <- to_waves(tlist)
   # Check if object is a list of lists
   if (!is.list(tlist[[1]])) {
     stop("Please declare a migraph-compatible network listed according
@@ -281,9 +330,12 @@ autographd <- function(tlist, layout, labels = TRUE,
           frame = ifelse(is.null(names(tlist)), i, names(tlist)[i])))
   # Check if all names are present in all lists
   if (length(unique(unname(lapply(tlist, length)))) != 1) {
-    tlist <- to_waves(as_tidygraph(do.call("rbind", edges_lst)),
-                      attribute = "frame")
-  }
+    if (any(c(node_shape, node_color, node_size) %in% names(node_attribute(tlist[[1]])))) {
+      node_info <- dplyr::distinct(do.call(rbind, lapply(1:length(tlist), function(i)
+        tlist[[i]] %>% activate("nodes") %>% data.frame()))) # keep node info for latter
+    } else node_info <- NULL
+    tlist <- to_waves(as_tidygraph(do.call("rbind", edges_lst)), attribute = "frame")
+  } else node_info <- NULL
   # Add separate layouts for each time point
   lay <- lapply(1:length(tlist), function(i)
     ggraph::create_layout(tlist[[i]], layout, ...))
@@ -294,7 +346,7 @@ autographd <- function(tlist, layout, labels = TRUE,
           frame = ifelse(is.null(names(tlist)), i, names(tlist)[i]))
   })
   # Create an edge list for each time point
-  edges_lst <- time_edges_lst(tlist, edges_lst, nodes_lst, edge_color)
+  edges_lst <- time_edges_lst(tlist, edges_lst, nodes_lst)
   # Get edge IDs for all edges
   all_edges <- do.call("rbind", lapply(tlist, igraph::get.edgelist))
   all_edges <- all_edges[!duplicated(all_edges), ]
@@ -304,6 +356,9 @@ autographd <- function(tlist, layout, labels = TRUE,
   # Bind nodes and edges list
   edges_out <- do.call("rbind", edges_lst)
   nodes_out <- do.call("rbind", nodes_lst)
+  if (!is.null(node_info)) {
+    nodes_out <- dplyr::left_join(nodes_out, node_info[!duplicated(node_info$name),], by = "name")
+  }
   # Delete nodes for each frame if isolate
   if (isFALSE(keep_isolates)) {
     nodes_out <- remove_isolates(edges_out, nodes_out)
@@ -326,6 +381,14 @@ autographd <- function(tlist, layout, labels = TRUE,
                      end_pause = 10, renderer = gganimate::gifski_renderer())
 }
 
+#' @rdname autographt
+#' @export
+autographd <- autographt
+
+#' @rdname autographt
+#' @export
+grapht <- autographt
+
 reduce_categories <- function(g, node_group) {
   limit <- toCondense <- NULL
   if (sum(table(node_attribute(g, node_group)) <= 2) > 2 &
@@ -370,7 +433,7 @@ reduce_categories <- function(g, node_group) {
   if ("x" %in% names(dots) & "y" %in% names(dots)) {
     lo <- ggraph::create_layout(g, layout = "manual",
                                 x = dots[["x"]], y = dots[["y"]])
-  } else lo <- ggraph::create_layout(g, layout, ...)
+  } else lo <- suppressWarnings(ggraph::create_layout(g, layout, ...))
   if ("graph" %in% names(attributes(lo))) {
     if (!setequal(names(as.data.frame(attr(lo, "graph"))), names(lo))) {
       for (n in setdiff(names(as.data.frame(attr(lo, "graph"))), names(lo))) {
@@ -378,12 +441,6 @@ reduce_categories <- function(g, node_group) {
       }
     }
   }
-  # if (layout == "stress" & .is_diamond(g)) {
-  #   turn <- matrix(c(cos(0.71), -sin(0.71), sin(0.71), cos(0.71)), 2, 2)
-  #   coord <- matrix(cbind(lo[,1], lo[,2]), ncol = 2) %*% turn
-  #   lo[,1] <- coord[,1]
-  #   lo[,2] <- coord[,2]
-  # }
   p <- ggraph::ggraph(lo) + ggplot2::theme_void()
   if (labels & is_labelled(g)) {
     if (layout == "circle") {
@@ -402,7 +459,7 @@ reduce_categories <- function(g, node_group) {
         hj <- ifelse(lo[,1] >= 0, -0.2, 1.2)
         vj <- ifelse(lo[,2] >= 0, -0.2, 1.2)
       }
-      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name),
+      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name), repel = TRUE,
                                       size = 3, hjust = hj, angle = angles) +
         ggplot2::coord_cartesian(xlim=c(-1.2,1.2), ylim=c(-1.2,1.2))
     } else if (layout == "concentric") {
@@ -416,31 +473,24 @@ reduce_categories <- function(g, node_group) {
         hj <- ifelse(lo[,1] >= 0, -0.2, 1.2)
         vj <- ifelse(lo[,2] >= 0, -0.2, 1.2)
       }
-      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name),
-                                      size = 3, hjust = hj,
-                                      vjust = vj, check_overlap = TRUE) +
+      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name),  vjust = vj,
+                                      size = 3, hjust = hj, repel = TRUE) +
         ggplot2::coord_cartesian(xlim=c(-1.2,1.2), ylim=c(-1.2,1.2))
-    } else if (layout %in% c("bipartite", "railway") |
-               (layout == "hierarchy" & length(unique(lo[,2])) <= 2)) {
-      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name),
-                                      size = 2, hjust = "outward",
-                                      nudge_y = ifelse(lo[,2] == 1, 0.05, -0.05),
-                                      # vjust = ifelse(node_mode(object), -1, 1),
-                                      angle = 90) +
+    } else if (layout %in% c("bipartite", "railway") | layout == "hierarchy" & length(unique(lo[["y"]])) <= 2) {
+      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name), angle = 90,
+                                      size = 3, hjust = "outward", repel = TRUE,
+                                      nudge_y = ifelse(lo[,2] == 1, 0.05, -0.05)) +
         ggplot2::coord_cartesian(ylim=c(-0.2, 1.2))
-    } else if (layout == "hierarchy" & length(unique(lo[,2])) > 2) {
-      p <- p + ggraph::geom_node_text(ggplot2::aes(label = name), size = 2,
-                                      hjust = "inward", vjust = -0.4)
-    } else if (!is_twomode(g)) { # Plot one mode
-      p <- p + ggraph::geom_node_label(ggplot2::aes(label = name),
-                                       label.padding = 0.15, label.size = 0,
-                                       repel = TRUE, seed = 1234)
-    } else { # Plot two modes
+    } else if (layout == "hierarchy" & length(unique(lo[["y"]])) > 2) {
       p <- p + ggraph::geom_node_text(ggplot2::aes(label = name),
-                                      repel = TRUE, size = 2,
-                                      hjust = "outward",
-                                      nudge_x = ifelse(lo[,1] == 1, 0.05, -0.05),
-                                      seed = 1234)
+                                      size = 3, hjust = "inward", repel = TRUE)
+    } else if (layout %in% c("alluvial", "lineage")) {
+      p <- p + ggraph::geom_node_label(ggplot2::aes(label = name), size = 3,
+                                       repel = TRUE, label.size = 0,
+                                       nudge_x = ifelse(lo[,1] == 1, 0.02, -0.02))
+    } else {
+      p <- p + ggraph::geom_node_label(ggplot2::aes(label = name), label.size = 0,
+                                       repel = TRUE, seed = 1234, size = 3)
     }
   }
   if (!is.null(node_group)) {
@@ -465,10 +515,9 @@ reduce_categories <- function(g, node_group) {
       if (!is.null(edge_color)) {
         if (edge_color %in% names(tie_attribute(g))) {
           p <- p + ggraph::geom_edge_arc(ggplot2::aes(
-            width = weight, colour = as.factor(tie_attribute(g, edge_color))),
+            width = esize, colour = as.factor(tie_attribute(g, edge_color))),
                                          edge_alpha = 0.4, strength = bend,
                                          edge_linetype = "solid",
-                                         edge_width = esize,
                                          arrow = ggplot2::arrow(angle = 15,
                                                                 length = ggplot2::unit(2, 'mm'),
                                                                 type = "closed"), 
@@ -477,11 +526,10 @@ reduce_categories <- function(g, node_group) {
             ggraph::scale_edge_colour_manual(values = colorsafe_palette,
                                              guide = ggplot2::guide_legend(""))
         } else {
-          p <- p + ggraph::geom_edge_arc(ggplot2::aes(width = weight),
+          p <- p + ggraph::geom_edge_arc(ggplot2::aes(width = esize),
                                          colour = edge_color,
                                          edge_alpha = 0.4, strength = bend,
                                          edge_linetype = "solid",
-                                         edge_width = esize,
                                          arrow = ggplot2::arrow(angle = 15,
                                                                 length = ggplot2::unit(2, 'mm'),
                                                                 type = "closed"), 
@@ -490,22 +538,20 @@ reduce_categories <- function(g, node_group) {
         }
       } else if (is_signed(g)) {
         p <- p + ggraph::geom_edge_arc(
-          ggplot2::aes(width = weight,
+          ggplot2::aes(width = esize,
                        colour = ifelse(igraph::E(g)$sign >= 0, "#d73027", "#4575b4"),
                        linetype = ifelse(igraph::E(g)$sign >= 0, "solid", "dashed")),
                                         edge_alpha = 0.4, strength = bend,
-                                        edge_width = esize,
                                         arrow = ggplot2::arrow(angle = 15,
                                                                length = ggplot2::unit(2, 'mm'),
                                                                type = "closed"), 
                                         end_cap = ggraph::circle(1.5, 'mm')) +
           ggraph::scale_edge_width_continuous(range = c(0.2, 2.5), guide = "none")
       } else {
-        p <- p + ggraph::geom_edge_arc(ggplot2::aes(width = weight),
+        p <- p + ggraph::geom_edge_arc(ggplot2::aes(width = esize),
                                         edge_colour = "black",
                                         edge_alpha = 0.4, strength = bend,
                                         edge_linetype = "solid",
-                                        edge_width = esize,
                                         arrow = ggplot2::arrow(angle = 15,
                                                                length = ggplot2::unit(2, 'mm'),
                                                                type = "closed"), 
@@ -559,16 +605,15 @@ reduce_categories <- function(g, node_group) {
       if (!is.null(edge_color)) {
         if (edge_color %in% names(tie_attribute(g))) {
         p <- p + ggraph::geom_edge_link0(ggplot2::aes(
-          width = weight, colour = as.factor(tie_attribute(g, edge_color))),
-                                        edge_alpha = 0.4, edge_linetype = "solid",
-                                        edge_width = esize) +
+          width = esize, colour = as.factor(tie_attribute(g, edge_color))),
+                                        edge_alpha = 0.4, edge_linetype = "solid") +
           ggraph::scale_edge_width_continuous(range = c(0.2, 1), guide = "none") +
           ggraph::scale_edge_colour_manual(values = colorsafe_palette,
                                            guide = ggplot2::guide_legend(""))
         } else {
           p <- p + ggraph::geom_edge_link0(ggplot2::aes(width = weight),
                                           colour = edge_color,
-                                          edge_alpha = 0.4, edge_width = esize,
+                                          edge_alpha = 0.4,
                                           edge_linetype = "solid") +
             ggraph::scale_edge_width_continuous(range = c(0.2, 1), guide = "none")
         }
@@ -577,13 +622,13 @@ reduce_categories <- function(g, node_group) {
           ggplot2::aes(width = weight,
                        colour = ifelse(igraph::E(g)$sign >= 0, "#d73027", "#4575b4"),
                        linetype = ifelse(igraph::E(g)$sign >= 0, "solid", "dashed")),
-          edge_alpha = 0.4, edge_width = esize) +
+          edge_alpha = 0.4) +
           ggraph::scale_edge_width_continuous(range = c(0.2, 1), guide = "none")
       } else {
         p <- p + ggraph::geom_edge_link0(ggplot2::aes(width = weight),
                                          edge_colour = "black",
                                          edge_linetype = "solid",
-                                         edge_alpha = 0.4, edge_width = esize) + 
+                                         edge_alpha = 0.4) + 
           ggraph::scale_edge_width_continuous(range = c(0.2, 1), guide = "none")
       }
     } else { # unweighted and undirected
@@ -686,7 +731,7 @@ reduce_categories <- function(g, node_group) {
     if (is_twomode(g)) {
       if (!is.null(node_color)) {
         if (node_color %in% names(node_attribute(g))) {
-          if (is_mark_attrib(node_attribute(g, node_color))) {
+          if (.is_mark_attrib(node_attribute(g, node_color))) {
             node_color <- factor(node_attribute(g, node_color),
                                  levels = c("TRUE", "FALSE"))
           } else node_color <- factor(node_attribute(g, node_color))
@@ -704,7 +749,7 @@ reduce_categories <- function(g, node_group) {
     } else {
       if (!is.null(node_color)) {
         if (node_color %in% names(node_attribute(g))) {
-          if (is_mark_attrib(node_attribute(g, node_color))) {
+          if (.is_mark_attrib(node_attribute(g, node_color))) {
             node_color <- factor(node_attribute(g, node_color),
                                  levels = c("TRUE", "FALSE"))
           } else node_color <- factor(node_attribute(g, node_color))
@@ -771,6 +816,8 @@ reduce_categories <- function(g, node_group) {
       out <- edge_size
     }
     if (length(out > 1) & all(out <= 1 & out >= 0)) out <- out*10
+  } else if (is.null(edge_size) & is_weighted(g)) {
+    out <- tie_attribute(g, "weight")
   } else {
     out <- 0.5
   }
@@ -795,16 +842,6 @@ reduce_categories <- function(g, node_group) {
   out
 }
 
-.is_diamond <- function(x) {
-  x <- as_matrix(x)
-  if (is.numeric(x)) {
-    if (length(x) == 100 | length(x) == 10000 &
-        suppressWarnings(all(unique(rowSums(x)) == c(3, 5, 8)))) {
-      TRUE
-    } else FALSE 
-  } else FALSE
-}
-
 .node_adoption_time <- function(g){
   diff_model <- attr(g, "diff_model")
   event <- nodes <- NULL
@@ -891,7 +928,7 @@ hypot <- function (x, y) {
 }
 
 time_edges_lst <- function(tlist, edges_lst, nodes_lst, edge_color) {
-  edg <- lapply(1:length(tlist), function(i) {
+  lapply(1:length(tlist), function(i) {
     edges_lst[[i]]$x <- nodes_lst[[i]]$x[match(edges_lst[[i]]$from,
                                                nodes_lst[[i]]$name)]
     edges_lst[[i]]$y <- nodes_lst[[i]]$y[match(edges_lst[[i]]$from,
@@ -904,10 +941,6 @@ time_edges_lst <- function(tlist, edges_lst, nodes_lst, edge_color) {
     edges_lst[[i]]$status <- TRUE
     edges_lst[[i]]
   })
-  # Keep only necessary columns
-  edg <- lapply(edg, function (x) x[,c("from", "to", "frame", "x", "y", "xend",
-                                       "yend", "id", "status"#, edge_color
-                                       )])
 }
 
 transition_edge_lst <- function(tlist, edges_lst, nodes_lst, all_edges) {
@@ -961,20 +994,15 @@ map_dynamic <- function(edges_out, nodes_out, edge_color, node_shape,
   # Plot edges
   if (!is.null(edge_color)) {
     # Remove NAs in edge color, if declared
-    edge_color <- ifelse(is.na(edges_out[[edge_color]]), "black", edges_out[[edge_color]])
-    color <- grDevices::colors()
-    color <- color[!color %in% "black"]
-    if(!any(grepl(paste(color, collapse = "|"), edge_color)) |
-       any(grepl("#", edge_color))) {
-      for(i in unique(edge_color)) {
-        if (i != "black") {
-          edge_color[edge_color == i] <- sample(color, 1)
-        }
-      }
+    if (edge_color %in% names(edges_out)) {
+      edge_color <- .check_color(edges_out[[edge_color]])
     }
-  } else edge_color <- rep("black", nrow(edges_out))
+  } else edge_color <- "black"
   if (!is.null(edge_size)) {
+    if (edge_size %in% names(edges_out)) {
     edge_size <- as.numeric(edges_out[[edge_size]])
+    edge_size <- ifelse(is.na(edge_size), 0.5, edge_size)
+    }
   } else edge_size <- 0.5
   p <- ggplot2::ggplot() + 
     ggplot2::geom_segment(aes(x = x, xend = xend, y = y, yend = yend, group = id),
@@ -982,22 +1010,16 @@ map_dynamic <- function(edges_out, nodes_out, edge_color, node_shape,
                           linewidth = edge_size, show.legend = FALSE)
   # Set node shape, color, and size
   if (!is.null(node_shape)) {
-    node_shape <- as.factor(nodes_out[[node_shape]])
-    node_shape <- c("circle", "square", "triangle")[node_shape]
-  } else node_shape <- rep("circle", nrow(nodes_out))
+    if (node_shape %in% names(nodes_out)) {
+      node_shape <- as.factor(nodes_out[[node_shape]])
+      if (!any(grepl("circle|square|triangle", node_shape))) {
+        node_shape <- c("circle", "square", "triangle")[node_shape]
+      }
+    }
+    } else node_shape <- "circle"
   if (!is.null(node_color)) {
     if (node_color %in% names(nodes_out)) {
-      node_color <- nodes_out[[node_color]]
-    }
-    color <- grDevices::colors()
-    color <- color[!color %in% "black"]
-    if (!any(grepl(paste(color, collapse = "|"), node_color)) |
-       any(grepl("#", node_color))) {
-      for(i in unique(node_color)) {
-        if (i != "black") {
-          node_color[node_color == i] <- sample(color, 1)
-        }
-      }
+      node_color <- .check_color(nodes_out[[node_color]])
     }
   } else if (is.null(node_color) & "Infected" %in% names(nodes_out)) {
     node_color <- as.factor(ifelse(nodes_out[["Exposed"]], "Exposed",
@@ -1014,8 +1036,7 @@ map_dynamic <- function(edges_out, nodes_out, edge_color, node_shape,
   } else node_size <- nrow(nodes_out)/length(unique(nodes_out$frame))
   # Add labels
   if (isTRUE(labels)) {
-    p <- p + ggplot2::geom_text(aes(x, y, label = name),
-                                alpha = alphad,
+    p <- p + ggplot2::geom_text(aes(x, y, label = name), alpha = alphad,
                                 data = nodes_out, color = "black",
                                 hjust = -0.2, vjust = -0.2, show.legend = FALSE)
   }
@@ -1039,24 +1060,37 @@ map_dynamic <- function(edges_out, nodes_out, edge_color, node_shape,
   p
 }
 
-collapse_guides <- function(plist) {
-  glist <- list()
-  for (i in seq_len(length(plist))) {
-    glist[[i]] <- names(which(apply(plist[[i]]$data[c("Infected", "Exposed",
-                                                      "Recovered")],
-                                    2, function(x) length(unique(x)) > 1)))
-  }
-  if (any(as.logical(lapply(glist, function(x) length(x) == 0))) &
-      length(unique(glist)) == 2 | length(unique(glist)) == 1 |
-      any(lengths(glist) > 1)) {
-    kl <- which.max(unlist(lapply(glist, length)))
-    for (i in setdiff(seq_len(length(plist)), kl)) {
-      plist[[i]]$guides <- NULL
+.check_color <- function(v) {
+  color <- grDevices::colors()
+  color <- color[!color %in% "black"]
+  v <- ifelse(is.na(v), "black", v)
+  if (!any(grepl(paste(color, collapse = "|"), v)) | any(grepl("#", v))) {
+    for(i in unique(v)) {
+      if (i != "black") {
+        v[v == i] <- sample(color, 1)
+      }
     }
   }
-  plist
+  v
 }
 
-is_mark_attrib <- function(x) {
+# .collapse_guides <- function(plist) {
+#   glist <- list()
+#   for (i in seq_len(length(plist))) {
+#     glist[[i]] <- names(which(apply(plist[[i]]$data[c("Infected",
+#                                                       "Exposed",
+#                                                       "Recovered")],
+#                                     2, function(x) length(unique(x)) > 1)))
+#   }
+#   if (any(lengths(glist) > 0)) {
+#     kl <- which.max(unlist(lapply(glist, length)))
+#     for (i in setdiff(seq_len(length(plist)), kl)) {
+#       plist[[i]]["guides"] <- NULL
+#     }
+#   }
+#   plist
+# }
+
+.is_mark_attrib <- function(x) {
   if ("node_mark" %in% class(x)) TRUE else FALSE
 }
