@@ -85,7 +85,7 @@ test_that("as_network converts correctly",{
 test_that("conversion of diff_model object works correctly", {
   skip_on_cran()
   skip_on_ci()
-  diff <- migraph::play_diffusion(ison_brandes)
+  diff <- play_diffusion(ison_brandes)
   tidy_diff <- as_tidygraph(diff)
   expect_equal(network_nodes(tidy_diff), network_nodes(ison_brandes))
   expect_equal(network_ties(tidy_diff), network_ties(ison_brandes))
