@@ -47,15 +47,12 @@ test_that("scales graph correctly", {
     autographr(node_color = color) +
     scale_color_uzh()
   test_rug <- ison_brandes %>%
-    mutate(color = c(rep(c(1,2,3), 3), 1, 2)) %>%
+    mutate(color = c(rep(c(1,2), 4), 1, 2, 1)) %>%
     autographr(node_color = color) +
     scale_color_rug()
-  # The `scale_name` field is deprecated from 3.5.0 onwards
-  skip_if(utils::packageVersion("ggplot2") >= "3.5.0")
-  expect_equal(test_sdg[["scales"]][["scales"]][[1]][["call"]][["scale_name"]], "SDGs")
-  expect_equal(test_sdg[["scales"]][["scales"]][[1]][["call"]][["palette"]][["palette"]], "SDGs")
-  expect_equal(test_iheid[["scales"]][["scales"]][[1]][["call"]][["scale_name"]], "IHEID")
-  expect_equal(test_ethz[["scales"]][["scales"]][[1]][["call"]][["scale_name"]], "ETHZ")
-  expect_equal(test_uzh[["scales"]][["scales"]][[1]][["call"]][["scale_name"]], "UZH")
-  expect_equal(test_rug[["scales"]][["scales"]][[1]][["call"]][["scale_name"]], "RUG")
+  expect_equal(as.character(test_sdg[["scales"]][["scales"]][[1]][["call"]]), "scale_color_sdgs")
+  expect_equal(as.character(test_iheid[["scales"]][["scales"]][[1]][["call"]]), "scale_color_iheid")
+  expect_equal(as.character(test_ethz[["scales"]][["scales"]][[1]][["call"]]), "scale_color_ethz")
+  expect_equal(as.character(test_uzh[["scales"]][["scales"]][[1]][["call"]]), "scale_color_uzh")
+  expect_equal(as.character(test_rug[["scales"]][["scales"]][[1]][["call"]]), "scale_color_rug")
 })
